@@ -1,7 +1,7 @@
 /* Copyright (C) 1997, 1998, 1999 Marius Vollmer
  * Copyright (C) 1999 John Harper <john@dcs.warwick.ac.uk>
  *
- * $Id: rep-gtk.h,v 1.23 2003/02/12 08:51:45 jsh Exp $
+ * $Id: rep-gtk.h 384 2008-10-18 18:07:11Z chrisb $
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -83,10 +83,10 @@ int sgtk_valid_uint (repv obj);
 int sgtk_valid_long (repv obj);
 int sgtk_valid_ulong (repv obj);
 int sgtk_valid_char (repv obj);
-repv sgtk_uint_to_rep (u_long x);
+repv sgtk_uint_to_rep (unsigned long x);
 repv sgtk_int_to_rep (long x);
 repv sgtk_long_to_rep (long x);
-repv sgtk_ulong_to_rep (u_long x);
+repv sgtk_ulong_to_rep (unsigned long x);
 guint sgtk_rep_to_uint (repv obj);
 gint sgtk_rep_to_int (repv obj);
 gulong sgtk_rep_to_ulong (repv obj);
@@ -277,10 +277,6 @@ GdkGC *gtk_style_bg_gc (GtkStyle *style, GtkStateType state);
 
 /* Gtk stuff that wouldn't be here in an ideal world. */
 
-#if GTK_MAJOR_VERSION == 1 && GTK_MINOR_VERSION == 0
-typedef int GtkWidgetFlags;
-#endif
-
 gchar *gtk_label_get_interp (GtkLabel *label);
 void gtk_menu_popup_interp (GtkMenu *menu,
 			    GtkWidget *parent_menu_shell,
@@ -289,20 +285,18 @@ void gtk_menu_popup_interp (GtkMenu *menu,
 			    guint32 activate_time,
 			    repv position);
 
+#if GTK_MAJOR_VERSION < 2 || (GTK_MAJOR_VERSION == 2 && GTK_MINOR_VERSION < 4)
 GtkWidget*
 gtk_radio_menu_item_new_with_label_from_widget (GtkRadioMenuItem *group,
-						gchar            *label);
+		                                                const gchar      *label);
 GtkWidget*
 gtk_radio_menu_item_new_with_mnemonic_from_widget (GtkRadioMenuItem *group,
-						   gchar            *label);
+		                                                   const gchar      *label);
 GtkWidget* gtk_radio_menu_item_new_from_widget (GtkRadioMenuItem *group);
-GtkWidget* gtk_pixmap_new_interp (char *file, GtkWidget *intended_parent);
-
-#ifndef HAVE_GDK_COLOR_COPY
-GdkColor*    gdk_color_copy     (GdkColor *);
-void         gdk_color_free     (GdkColor *);
 #endif
 
+GtkWidget* gtk_pixmap_new_interp (char *file, GtkWidget *intended_parent);
+
 GdkColor *gdk_color_parse_interp (char *spec);
 GdkColor *gtk_style_get_white_interp (GtkStyle *style);
 
