@@ -1,18 +1,18 @@
 /* Copyright (C) 1997, 1998, 1999 Marius Vollmer
  * Copyright (C) 1999-2000 John Harper <john@dcs.warwick.ac.uk>
  *
- * $Id: rep-types.c,v 1.6 2000/07/23 22:52:56 john Exp $
+ * $Id: rep-types.c 406 2009-02-01 21:57:53Z chrisb $
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2, or (at your option)
  * any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this software; see the file COPYING.  If not, write to
  * the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
@@ -66,7 +66,7 @@ sgtk_valid_char (repv obj)
 }
 
 repv
-sgtk_uint_to_rep (u_long x)
+sgtk_uint_to_rep (unsigned long x)
 {
     return rep_make_long_uint (x);
 }
@@ -84,7 +84,7 @@ sgtk_long_to_rep (long x)
 }
 
 repv
-sgtk_ulong_to_rep (u_long x)
+sgtk_ulong_to_rep (unsigned long x)
 {
     return rep_make_long_uint (x);
 }
@@ -128,7 +128,7 @@ sgtk_char_to_rep (gchar c)
 char *
 sgtk_rep_to_string (repv obj)
 {
-    return rep_STRINGP (obj) ? rep_STR (obj) : (u_char *)"";
+    return rep_STRINGP (obj) ? rep_STR (obj) : (unsigned char *)"";
 }
 
 repv
@@ -232,6 +232,13 @@ list_length (repv list)
     return (len && rep_INTP (len)) ? rep_INT (len) : 0;
 }
 
+/* namespace fuckage. needed so we can represent GObject base class */
+GType
+gobject_get_type (void)
+{
+  return G_TYPE_OBJECT;
+}
+
 
 /* Floats. */
 
@@ -423,7 +430,7 @@ GList*
 sgtk_rep_to_list (repv obj, void (*fromscm)(repv, void*))
 {
   GList *res = NULL, *tail;
-  
+
   if (obj == Qnil || (rep_CONSP(obj)))
     {
       while (rep_CONSP(obj))
@@ -431,7 +438,7 @@ sgtk_rep_to_list (repv obj, void (*fromscm)(repv, void*))
         GList *n = g_list_alloc ();
 	if (res == NULL)
 	  res = tail = n;
-	else 
+	else
 	  {
 	    g_list_concat (tail, n);
 	    tail = n;
@@ -452,7 +459,7 @@ sgtk_rep_to_list (repv obj, void (*fromscm)(repv, void*))
 	  GList *n = g_list_alloc ();
 	  if (res == NULL)
 	    res = tail = n;
-	  else 
+	  else
 	    {
 	      g_list_concat (tail, n);
 	      tail = n;
@@ -491,7 +498,7 @@ sgtk_list_finish (GList *list, repv obj, repv (*toscm)(void*))
 	    }
 	}
     }
-  
+
   g_list_free (list);
 }
 
@@ -587,8 +594,6 @@ sgtk_cvec_to_rep (sgtk_cvec *cvec, repv (*toscm)(void *), size_t sz)
 repv
 rep_dl_init (void)
 {
-    repv tem = rep_push_structure ("gui.gtk.types");
-    /* ::alias:sgtk-types gui.gtk.types:: */
-    rep_alias_structure ("sgtk-types");
+    repv tem = rep_push_structure ("gui.gtk-2.types");
     return rep_pop_structure (tem);
 }
